#
# spec file for package xfce4-settings
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git

Name:           xfce4-settings
Version:        4.20.1
Release:        1.1
Summary:        Tools for Managing Xfce Settings
License:        GPL-2.0-only AND GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfce4-settings/start
Source:         https://archive.xfce.org/src/xfce/xfce4-settings/4.20/%{name}-%{version}.tar.bz2
BuildRequires:  gettext >= 0.19.8
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(exo-2) >= 0.11.0
BuildRequires:  pkgconfig(fontconfig) >= 2.6.0
BuildRequires:  pkgconfig(garcon-1) >= 0.1.10
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gtk-layer-shell-0) >= 0.7.0
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libnotify) >= 0.7.8
BuildRequires:  pkgconfig(libxfce4kbd-private-3) >= 4.19.5
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.19.5
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.17.2
BuildRequires:  pkgconfig(libxfconf-0) >= 4.19.3
BuildRequires:  pkgconfig(libxklavier) >= 5.0
BuildRequires:  pkgconfig(upower-glib) >= 0.99.10
BuildRequires:  pkgconfig(wayland-client) >= 1.20
BuildRequires:  pkgconfig(wayland-scanner) >= 1.20
BuildRequires:  pkgconfig(x11) >= 1.6.7
BuildRequires:  pkgconfig(xcursor) >= 1.1.0
BuildRequires:  pkgconfig(xi) >= 1.2.0
BuildRequires:  pkgconfig(xorg-libinput) >= 0.6.0
BuildRequires:  pkgconfig(xrandr) >= 1.5.0
%if 0%{?suse_version} > 1500
BuildRequires:  xorgproto-devel
%endif
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       %{name}-branding = %{version}
Recommends:     %{name}-color
Recommends:     %{name}-lang = %{version}
Provides:       xfce-mcs-manager = %{version}
Obsoletes:      xfce-mcs-manager < %{version}
Provides:       xfce-mcs-plugins = %{version}
Obsoletes:      xfce-mcs-plugins < %{version}

%description
This package provides a number of tools for managing settings in the Xfce
desktop environment.

%package branding-upstream
Summary:        Upstream Branding of xfce4-settings
Group:          System/GUI/XFCE
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
#BRAND: xsettings.xml: Determines diverse settings including the default theme
#BRAND: and anti-aliasing default settings.
#BRAND: xfce-settings-manager.menu: Configures the settings manager menu.
BuildArch:      noarch

%description branding-upstream
This package provides the upstream look and feel for xfce4-settings.

%package color
Summary:        Subpackage providing xfce4-color-settings
BuildRequires:  sane-backends
BuildRequires:  xiccd
BuildRequires:  pkgconfig(colord) >= 0.3.0
BuildRequires:  pkgconfig(colord-gtk) >= 0.3.0
# Make sure colord and other runtime dependencies are installed boo#1173953
Requires:       colord
Requires:       %{name} = %{version}-%{release}
Requires:       sane-backends
Requires:       xiccd
Provides:       xfce4-color-settings

%description color
The Xfce Color Profile settings tool is a front-end to set up color management
for printers, scanners, and displays.

%lang_package

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
export CFLAGS="%{optflags} -D_FORTIFY_SOURCE=1"
%configure \
    --enable-maintainer-mode \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-sound-settings \
    --enable-colord \
    --enable-pluggable-dialogs
%else
%configure \
    --with-helper-path-prefix=%{_libexecdir} \
    --enable-sound-settings \
    --enable-colord \
    --enable-pluggable-dialogs
%endif
%make_build

%install
%make_install

%suse_update_desktop_file xfsettingsd
# add back X-XFCE for now
%suse_update_desktop_file xfce-display-settings X-XFCE
# add back X-XFCE for now
%suse_update_desktop_file xfce-keyboard-settings X-XFCE
# add back X-XFCE for now
%suse_update_desktop_file xfce-mouse-settings X-XFCE
# add back X-XFCE for now
%suse_update_desktop_file xfce-settings-manager X-XFCE
# add back X-XFCE for now
%suse_update_desktop_file xfce-ui-settings X-XFCE
# add back X-XFCE for now; this is a personal and not a system setting
%suse_update_desktop_file -r xfce4-accessibility-settings XFCE X-XFCE GTK Settings DesktopSettings X-XFCE-SettingsDialog X-XFCE-PersonalSettings
# add back X-XFCE for now; this is a personal and not a system setting
%suse_update_desktop_file -r xfce4-mime-settings XFCE X-XFCE GTK Settings DesktopSettings X-XFCE-SettingsDialog X-XFCE-PersonalSettings
# add back X-XFCE for now
%suse_update_desktop_file xfce4-settings-editor X-XFCE

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

# Fix python shebangs
sed -i 's+#!/usr/bin/env python3+#!/usr/bin/python3+g' %{buildroot}%{_libexecdir}/xfce4/xfce4-compose-mail

%find_lang %{name} %{?no_lang_C}

%files
%doc AUTHORS NEWS README.md
%license COPYING
%{_bindir}/xfce4-accessibility-settings
%{_bindir}/xfce4-appearance-settings
%{_bindir}/xfce4-display-settings
%{_bindir}/xfce4-find-cursor
%{_bindir}/xfce4-keyboard-settings
%{_bindir}/xfce4-mime-helper
%{_bindir}/xfce4-mouse-settings
%{_bindir}/xfce4-settings-editor
%{_bindir}/xfce4-settings-manager
%{_bindir}/xfsettingsd
%{_bindir}/xfce4-mime-settings
%dir %{_libexecdir}/xfce4/settings/
%{_libexecdir}/xfce4/settings/appearance-install-theme
%{_libexecdir}/xfce4/xfce4-compose-mail
%dir %{_datadir}/applications/
%{_datadir}/applications/xfce-display-settings.desktop
%{_datadir}/applications/xfce-keyboard-settings.desktop
%{_datadir}/applications/xfce-mouse-settings.desktop
%{_datadir}/applications/xfce-settings-manager.desktop
%{_datadir}/applications/xfce-ui-settings.desktop
%{_datadir}/applications/xfce4-accessibility-settings.desktop
%{_datadir}/applications/xfce4-file-manager.desktop
%{_datadir}/applications/xfce4-mail-reader.desktop
%{_datadir}/applications/xfce4-mime-settings.desktop
%{_datadir}/applications/xfce4-settings-editor.desktop
%{_datadir}/applications/xfce4-terminal-emulator.desktop
%{_datadir}/applications/xfce4-web-browser.desktop
%{_sysconfdir}/xdg/autostart/xfsettingsd.desktop
%dir %{_datadir}/icons/hicolor/
%{_datadir}/icons/hicolor/*/*/org.xfce.filemanager.*
%{_datadir}/icons/hicolor/*/*/org.xfce.mailreader.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.accessibility.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.appearance.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.default-applications.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.display.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.editor.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.keyboard.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.manager.*
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.mouse.*
%{_datadir}/icons/hicolor/*/*/org.xfce.terminalemulator.*
%{_datadir}/icons/hicolor/*/*/org.xfce.webbrowser.*
%{_datadir}/icons/hicolor/*/*/xfce-display-*.*
%dir %{_datadir}/xfce4/helpers
%{_datadir}/xfce4/helpers/*.desktop
%dir %{_libdir}/gtk-3.0/modules
%{_libdir}/gtk-3.0/modules/*

%files lang -f %{name}.lang

%files branding-upstream
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xsettings.xml
%dir %{_sysconfdir}/xdg/menus
%{_sysconfdir}/xdg/menus/xfce-settings-manager.menu
%config %{_sysconfdir}/xdg/xfce4/helpers.rc

%files color
%{_bindir}/xfce4-color-settings
%dir %{_datadir}/applications/
%{_datadir}/applications/xfce4-color-settings.desktop
%dir %{_datadir}/icons/hicolor/
%{_datadir}/icons/hicolor/*/*/org.xfce.settings.color.*

%changelog
* Sun Feb  9 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.1:
  * Update copyright year
  * build: Add missing dep flags
  * scan-build: Fix core.uninitialized.Assign
  * build: Install missing helper opera-mailer.desktop
  * build: Make gio-unix mandatory
  * build: Simplify libxklavier version management
  * Bump xfconf min version
  * x11: displays: Delay RRScreenChangeNotify handling when DPMSModeOff
  * build: Fix -Wmaybe-uninitialized
  * xfsettingsd: Fix error handling in main()
  * xfsettingsd: Don't disable DPI setting by default
  * wayland: common: Add missing struct member initialization
  * displays: Always enable first output
  * Translation Updates
- Remove obsolete patch 0001-relax-x11-version.patch
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0:
  * xfsettingsd: Fix ushort and ulong types on FreeBSD
  * Translation Updates
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.4 [development release]
  * I18n: Update po/LINGUAS list
  * mime: Fix xfce_mime_helper_category_to_string leak
  * mime: Fix argument string leaks
  * reinstate sys/wait.h inclusion, needed for WEXITSTATUS at least
    on OpenBSD
  * mime: Fix error message for missing helper definition
  * Translation Updates
- Refresh 0001-relax-x11-version.patch
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.3 [development release]
  * Added Keywords/Categories fields to .desktop files
  * display-settings: Fix InputRegion leak
  * x11: displays: Refactor screen_on_event()
  * x11: displays: Delay RRScreenChangeNotify handling
  * wayland: common: Properly initialize output modes
  * color-settings: Add missing translation
  * build: Adjust Wayland requirements for Xfce 4.20
  * build: Bump requirements for Xfce 4.20
  * xfsettingsd: Fix GVariant leak
  * Use a toggle button for the MIME chooser dropdown buttons
  * Revert "mime: Fix UMRs with GdkEvent"
  * mime: Fix UMRs with GdkEvent
  * mime: Fix string leak
  * display-settings: Fix XfceMode leak
  * mime: Fix GOptionContext leak
  * mouse: Fix XGetExtensionVersion leaks
  * mime: Fix leak in xfce_mime_window_row_activated
  * mime: Fix GList leak in xfce_mime_helper_chooser_pressed
  * mime: Fix xfce_mime_helper_category_to_string leak
  * mime: Fix xfce_str_replace leak
  * mime: Fix icon leaks
  * mime: Fix g_option_context_get_help leak
  * mime: Fix AtkRelationSet leak
  * build: Fix build with libxfce4ui master
  * xfsettingsd: pointers: Allow changing the size of device property
    array
  * display-settings: Add missing translation
  * Enumerate/load icon themes off of the UI thread
  * appearance-settings: Fix memory leak
  * Fix gtk-layer-shell includes
  * appearance-settings: Fix scrolling via arrow keys in gtk theme list
  * display-settings: Update primary monitor status on setting change
  * display-settings: Fix primary monitor status for xfce4-notifyd
  * display-settings: Fix primary monitor status for xfce4-panel
  * xfsettingsd: Fix client side decoration layout
  * x11: displays: Really honor /Notify is set to "Do nothing"
  * Revert "x11: displays: Disable new outputs if /Notify is set to "Do
    nothing""
  * mime-settings: Override GtkDialog::response()
  * settings-manager: Add xfce4-about
  * settings-manager: Remove xscreensaver
  * scan-build: Fix unix.Malloc
  * scan-build: Fix deadcode.DeadStores
  * scan-build: Add false positive file
  * gcc-analyzer: Add false positive file
  * build: clang: Fix -Wimplicit-const-int-float-conversion
  * build: clang: Fix -Wcast-align
  * build: clang: Fix -Wignored-attributes
  * keyboard-settings: Escape markup characters in command tooltips
  * build: Fix build with --enable-sound-settings
  * wayland: appearance-settings: Hide Xft settings
  * mouse-settings: Fixes reverse horizontal scrolling
  * display-settings: Listen to output change for minimal dialog too
  * display-settings: Avoid weird interact between main and minimal
    dialogs
  * xfsettingsd: Use default display profile when several profiles match
  * Revert "Add new CI builds to build without X11 and Wayland"
  * Apply .clang-format file
  * Remove unnecessary dirname in local includes
  * clang-format: Use IncludeBlocks::Regroup
  * Apply .clang-format file
  * Preliminary cleanup
  * Bump required versions and remove dead code
  * Clean up and sort includes
  * clang-format: Add file
  * xfce-randr: Take RR_DoubleScan and RR_Interlace flags into account
  * appearance-settings: Show warnings for incomplete icon themes
  * build: Fix x11 detection by defining the right m4 macro
  * Translation Updates
- Add 0001-relax-x11-version.patch to allow build for Leap with its
  ancient but sufficient X11 packages.
- Remove obsolete patch 0001-add-missing-include.patch
* Fri Oct 25 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add 0001-add-missing-include.patch to add missing prototype detected
  by building with gcc-14 on Tumbleweed.
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Updated to version 4.19.2 (development branch)
* Thu Nov 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.4
  * display-settings: Fix memory management of confirmation dialog
  * xfsettingsd: displays: Always do some actions on RRScreenChangeNotify
  * xfsettingsd: displays: Fix memory leak
  * settings-manager: Support absolute path as icon name
  * Replace deprecated xfce_spawn(_command_line)?_on_screen
  * appearance: Match more dark themes (fixes #495)
  * appearance: Check for presence of color-scheme key
  * Apply matching xfwm4 when the switch is clicked
  * displays: Lower warning level
  * Translation Updates
* Tue Jul  4 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.3
  * Displays: Fix finding a valid mode by refresh rate
  * dialogs: Secure use of GSettings
  * xfsettingsd: Fix wrong test for property removal
  * xfsettingsd: Update also the type when updating a value
  * keyboard-settings: Fix critical when opening layout selection
    dialog
  * appearance-install-theme: Fix error message
  * appearance-install-theme: Do not mention file size in error
    message
  * appearance-install-theme: Check for theme package validity
  * appearance-install-theme: Update GTK icon cache after installing
  * appearance-install-theme: detect icon themes first (#271)
  * appearance-install-theme: make cleanup safer
  * appearance-install-theme: Use recommended way of command
    substitution.
  * appearance-install-theme: Convert to POSIX
  * Update bug report address
  * display: Check for XError on transform apply
  * Translation Updates
* Sat Feb 11 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Update copyright year
  * mime-settings: Increase dialog size (!96)
  * display: fix blurry 'help' indicator on output (#400, !95)
  * display: fix blurry icon in profiles treeview
  * display: fix blurry icons in minimal display settings dialog
  * mime: fix blurry icons in default app menus
  * mouse: fix blurriness in cursor theme previews
  * appearance: fix blurry subpixel antialias icons
  * appearance: fix blurry icon theme previews
  * xfsettingsd: Make xsettings.xml well-formed (Fixes #431, !94)
  * xfsettingsd: Remove duplicated config line (Fixes #425)
  * Translation Updates
* Thu Dec 22 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.1
  * xfsettingsd: Make CSD (client side decorations) for dialogs opt-in
  * Translation Updates
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 4.18.0:
  * build: Bump requirements for Xfce 4.18
  * appearance: Sync color scheme to gsettings
  * appearance: Fix mem leaks
  * settings-manager: Add padding to embedded dialogs
  * display-settings: Search for clonable modes only by resolution
  * Bumped copyright to 2022
  * mime-settings: Properly quote command parameters
  * Revert "Escape characters which do not belong into an URI/URL
    (gxo#xfce/xfce4-settings#390)
  * Escape characters which do not belong into an URI/URL
  * mime-helpers: Add Alacritty and kitty
  * color-settings: Destroy dialog before releasing its GtkBuilder
  * dialogs: Revert type hint changes
  * Improve wording
  * Add binding for /Gtk/DialogsUseHeader in appearance dialog
  * appearance: Fix theme list selection
  * xfce-mime-helper: exo_str_is_equal -> g_strcmp0
  * xfce4-mime-helper: Prefer full command when basic command is env
  * Add Flatpak binaries
  * Fix a recursive lock in libX11.
  * appearance: Code style fixes
  * appearance: Fix SyncThemes property path and default value
  * Add addional checks to xfce_settings_editor_box_selection_changed
  * Fix invalid cast error
  * Fix $DISPLAY being set to wrong value
  * build: Fix intltool lock file problem during make distcheck
  * color-settings: Fix ColorSettings release
  * Add search bar to search per component
  * Use 2 decimals for refresh rate
  * display: Select next preset when minimal dialog is activated
  * display: Add helper functions
  * Update COPYING
  * Replace deprecated spawn_command_line_on_screen with
  * spawn_command_line
  * Fix help button action
  * Updated required libxfce4util version
  * Remove dependence on exo-string
  * settings-manager: Always show the search entry, no slider, no button
  * display: Add 'autoconnect mode' setting
  * Switch to using xfce_gtk_label_set_a11y_relation
  * keyboard: Mark system defaults switch as active
  * Revert "keyboard: Correctly initialize setting (gxo#xfce/xfce4-settings#310)"
  * keyboard: Correctly initialize setting
  * keyboard: Fix icon name in settings dialog
  * xfsettingsd: Fix setting float array properties
  * keyboard: Make buttons translatable
  * mime-settings: Allow filtering by application name
  * Drop preferences-desktop-default-applications icon name
  * display: Switch to MessageDialog for confirmation
  * display: Fix scale by rounding
  * appearance: Add option to sync xfwm4 theme
  * display: Add 1.25 and 1.75 ratios to presets
  * Remove unused variable
  * Default to using /tmp for temporary directory base if both
  * XDG_CACHE_HOME and TMPDIR are not defined in the environment.
  * Also allocate terminating element
  * Translation updates
* Wed Nov 16 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.16.5
  * Fix regression introduced in 4.16.4: "exo-open" not working
    for paths with spaces inside (gxo#xfce/xfce4-settings#403)
* Wed Nov  9 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.16.4
  * Escape characters which do not belong into an URI/URL (gxo#xfce/xfce4-settings#390)
  * Prefer full command when basic command is env (gxo#xfce/xfce4-settings#358)
* Tue Jul  5 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.3
  * xfsettingsd: Fix recursive lock in libX11
    (gxo#xfce/xfce4-settings#369 boo#1200468)
  * build: Fix intltool lock file problem during make distcheck
  * Translation Updates
* Thu Jan 20 2022 Maurizio Galli <maurizio.galli@suse.com>
- Fix runtime dependencies for xfce4-color-settings and replace Supplements
  with Recommends from the main package
* Tue Dec  7 2021 Maurizio Galli <maurizio.galli@suse.com>
- Split xfce4-color-settings in a subpackage with appropriate dependencies
  (boo#1173953)
* Tue Jun  8 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.2
  - keyboard: Mark system defaults switch as active
    (gxo#xfce/xfce4-settings#310 and boo#1181263)
  - keyboard: Correctly initialize setting
    (gxo#xfce/xfce4-settings#310 and boo#1181263)
  - keyboard: Fix icon name in settings dialog
  - keyboard: Make buttons translatable (gxo#xfce/xfce4-settings#306)
  - xfsettingsd: Fix setting float array properties
  - Translation Updates
* Mon Apr 12 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.16.1
  * display: Fix scale by rounding (gxo#xfce/xfce4-settings#258)
  * Drop preferences-desktop-default-applications icon name
  * Also allocate terminating element
  * Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  - Drop subtitles from settings dialogs
    (Fixes gxo#xfce/xfce4-settings#239)
  - display: Fix icon name in settings dialog
  - settings-manager: Fix visibility of filterbar
  - settings-manager: Correctly show/hide the filterbar
  - settings-manager: Switch to GtkSearchEntry
  - settings-manager: Put filter in separate bar
    (Fixes gxo#xfce/xfce4-settings#226)
  - appearance: Add 'Add' button to install themes
    (Fixes gxo#xfce/xfce4-settings#193)
  - color: Tweak colors  of icon
  - mime: Accept Thunar's old id name (Fixes gxo#xfce/xfce4-settings#247)
  - settings-editor: Enable tooltips and ellipsizing for `Value` column
  - settings-editor: Fix scrollbar for channels
  - settings-editor: Point to correct docs URL
    (gxo#xfce/xfce4-settings#245)
  - bump glib (and gio, gthread, etc) minimum to 2.50.0
  - Remove GSourceFunc casts
  - Indentation fixes
  - Translation Updates
* Sun Nov 15 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.15.3
  - Disable UPower support by default
  - Add 24px and 32px icons
  - xfsettingsd: avoid default double fork
  - mime: Add 'Open with...' button
  - mime: Add new generic launcher icons
  - color: Adjust padding of dialog
  - color: Add labels to toolbar
  - keyboard: Make 'system defaults' a GtkSwitch
  - keyboard: Adjust width of shortcut column (gxo#xfce/xfce4-settings#223)
  - keyboard: Update dialog UI
  - keyboard: Make all table columns sortable
  - keyboard: Improve inline toolbar alignment
  - display: Center minimal dialog on monitor where cursor is
  - settings-editor: Add labels to toolbar items
  - Update README file
  - Translation Updates
- Fixed python shebangs warning
* Thu Nov  5 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Resolve file conflict with xfce4-branding-openSUSE
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.2
  * appearance: Fix width of DPI spinbutton (bxo#16125)
  * appearence: Sync theme, icon, font names to gsettings
  * appearance: Fix list refresh on DnD (gxo#xfce/xfce4-settings#213)
  * appearance: Drop toolbar style setting (bxo#16665)
  * display: Initial fractional scaling support
    (gxo#xfce/xfce4-settings#162)
  * display: Custom scale changes are display changes
  * display: Improve layout in settings dialog
  * display: Resize display widget according to scale
  * display: Move scaling presets to glade
  * display: Set minimum scale to 0.1
  * display: Improve state machine for scaling option
  * xfsettingsd: Correctly get current xrandr scale
  * mime-settings: Rename dialog and icon to 'Default Applications'
  * mime-settings: Fix window icon name
  * mime-settings: Fix double free
  * mime-helpers: Fix Nautilus icon name
  * mime-helpers: Rename Thunar to thunar
  * Rename Thunar to thunar in make and potfiles
  * Expand desktop entry field codes
  * keyboard-settings: Support libxfce4ui XfceTitledDialog new API
  * keyboard: Show shortcuts with keycap class
  * settings-manager: Ensure searchbox has initial focus (bxo#16890)
  * settings-manager: Simplify redrawing of search results
    (gxo#xfce/xfce4-settings#141)
  * settings-manager: Hide filter entry in plugged dialogs
  * Convert xfce4-compose-mail to Python
  * Add dependency to Python3
  * Use just binary name (instead of full path) as argument
  * Don't crash when upowerd isnt present (bug #60)
  * Always install shiny new icons
  * Drop libxfce4ui 4.15.1 ifdefs
  * exo-compose-email -> xfce4-compose-email
  * exo-helper -> xfce4-mime-helper
  * mime-settings now includes preferred applications
  * Switch to new app icons and rDNS icon names
  * Increase mouse cursor upper bound for HiDPI (bxo#16042)
  * Make "Profiles matching" sentence translatable (bxo#16679)
  * settings-manager: Use symbolic find/clear icons
  * Move from exo-csource to xdt-csource (bxo#16717)
  * Handle failure to get Xkl engine for display (bxo#16017)
  * settings-manager: Make sure content determines size
  * Fix GTimeVal deprecation (bxo#16645)
  * Fix keywords and mark them  as translateable
  * Use proper fallback configuration on "apply" and "toggle off"
    (bxo#16476)
  * keyboard-settings: Fix log flood (bxo#16521)
  * keyboard: Fix crash when editing shortcut (bxo#15958)
  * Add keywords to .desktop files (bxo#10694)
  * settings-manager: Improve search by including keywords
    (bxo#10694)
  * xfsettingsd: Add --disable-wm-check flag (bxo#16128)
  * Set "gtk-titlebar-middle-click" to "lower" by default
  * display: Allow resizing of minimal dialog (bxo#15450)
  * settings-manager: Show min and max buttons
  * dialogs: Ensure dialogs have min and max buttons
  * xsettings: Use CSD for GtkDialogs by default
  * settings-manager: Fix XfceTitledDialog layout with CSD
  * settings-manager: Drop setting the old header style
  * display: Show ratio next to display resolution
  * display: Mark preferred mode with an asterisk
  * display: Add init function for aspect ratios
  * display: Right-align the display ratio
  * display: Fixed warning and removed ratio
  * display: Improve look of ratio
  * display: Fix icon name for primary indicator
  * display: Initialize crtc->scalex/y (bxo#15971)
  * settings-editor: Add consistent inline-toolbar
  * appearance: Only show themes that support Gtk3 (bxo#15849)
  * color: Fix crash in add-profiles dialog (bxo#15876)
  * color: Conditionally hide info button in add-profile dialog
  * color: Add tooltip to profile info buttons
  * display: Fix profile matching in xfsettingsd
  * display: Assure correct gchar** (bxo#15816)
  * keyboard: Improve layout of add-command dialog
  * keyboard: Add mnemonics to add-command dialog (bxo#10495)
  * Switch to symbolic window-close icon
  * Bump libxfce4ui dependency to 4.15.1
  * Improve string for session managers
  * Ensure the newly labeled 'Xfce Settings Daemon' is translated
  * Do not show translation info on --help output
  * Translation Updates
* Mon Apr 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.3
  * display: Allow resizing of minimal dialog (bxo#15450)
  * display: Use proper fallback configuration on "apply" and
    "toggle off" (bxo#16476)
  * keyboard: Fix crash when editing shortcut (bxo#15958)
  * keyboard: Fix log flood (bxo#16521)
  * settings-manager: Make sure content determines size
  * xfsettingsd: Handle failure to get Xkl engine for display
    (bxo#16017)
  * Translation Updates
* Sun Jan 12 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.2
  * display: Fix icon name for primary indicator
  * display: Initialize crtc->scalex/y (bxo#15971)
  * appearance: Only show themes that support Gtk3 (bxo#15849)
  * color: Fix crash in add-profiles dialog (bxo#15876)
  * Translation Updates
* Thu Aug 22 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.14.1
  * display: Fix profile matching in xfsettingsd
  * display: Assure correct gchar** (bxo#15816)
  * color: Conditionally hide info button in add-profile dialog
  * color: Add tooltip to profile info buttons
  * keyboard: Add mnemonics to add-command dialog (bxo#10495)
  * keyboard: Improve layout of add-command dialog
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Enable colord support
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * a11y: Replace GtkStock buttons
  * appearance: Replace GtkStock buttons
  * color: Replace GtkStock buttons
  * display: Don't warn on deleting last profile
  * display: Fix settings retention (bxo#15437)
  * display: Remove debug statement breaking profiles (bxo#15769)
  * display: Use proper icon name
  * keyboard: Replace GtkStock buttons
  * Make strings translatable
  * mouse: Replace GtkStock buttons
  * settings-editor: Fix buttons declaration
  * settings-editor: Replace GtkStock buttons
  * Translation Updates
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.7
  * display: Sync display when applying config
  * display: Use current display
  * xsettings: Grab and sync XServer on startup (bxo#15725)
  * xfsettingsd: Start settings prior to complete startup (bxo#15725)
  * Update copyright years
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.7
  * color:
  - Fix crash when launching gcm in plugged dialog (bxo#15426)
  - Set correct icon in color dialogs
  * display:
  - Replace deprecated icon (bxo#15416)
  - Add mnemonics to minimal dialog buttons (bxo#15449)
  - Disable auto-enabling profiles by default
  * settings-manager: Fix missing icons on resize/add/remove
    (bxo#15428, bxo#15613)
  * xfsettingsd: Fix numlock state restoration (bxo#15642)
  * Translation updates
* Wed Jun  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added OBS service file to enable only for GIT Master aka RAT
* Fri May 17 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 4.13.6
  * New Feature: Add color-settings (colord frontend)
  * New Feature: Add display profile support to the daemon
  * Bugfixes and other smaller changes:
  - display:
  - Track and highlight active profile
  - Ask user to update profile when closing with unsaved
    changes
  - Add interactive information about primary display setting
  - Improve profile-create popover
  - Improve profile-delete dialog
  - UI alignment improvements
  - Reduce complexity of the code and speedup
    display_settings_get_profiles
  - Replace deprecated GtkStock
  - Re-introduce display numbering
  - Ensure the settomgs dialog gets properly destroyed
  - Verify unique profile names
  - Drop connector name from profile matching
  - Correctly fall back to previous profile on cancel
  - Fix alignment of buttons in minimal dialog
  - Only show profiles which match *all* connected displays
  - Update profile list on screen changes
  - Fix crash when no RRMode is available (bxo#12607)
  - Correctly hide primary setting with 1 display
  - Fix calculation of offset
  - Always show the 'primary display' option
  - Make primary indicator a star icon
  - Throw warning when monitors exceed max screen size
  - color: Always select first device on startup (bxo#15266)
  - xfsettingsd: Increase startup priority
  - Fix scrolling in embedded settings dialogs (bxo#14285,
    lp#1653448)
  - Fix search change clearing and hiding sections (bxo#14792)
  - Resolved g_type_class_add_private deprecations (GObject 2.58)
  - Fix incremental sending from the clipboard manager (bxo#13537)
  - Fix WindowScalingFactory property type
  - Fix code spacing
  - Fix memory leaks
  - Fix CID 337242: Null pointer dereferences (REVERSE_INULL)
  - Fix compiler warnings
  - Fix icon names
  - Update configure.ac.in
  - Update .gitignore
  - Set yes as the default debxolevel
  * Translation Updates
* Tue Apr 30 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 4.13.5
  - New: Add display profiles feature
  - Allows for saving/restoring display configurations
  - Profiles can be auto-applied when new displays are connected
  - Drop the Gtk Theme previews
  - Various UI improvements to the settings dialogs
  - New icons for the minimal display dialog
  - Fix: Fix broken hover effect in the settings manager (bxo#14539)
  - Fix: Add default mnemonics back to dialog buttons
  - Fix: Add DBUS_GLIB_CFLAGS for Settings Editor (bxo#14385)
  - Fix: Force using a period as a decimal separator in xfsettingsd (bxo#11906)
  - Translation updates
- Changes from 4.13.4
  - Fix: Redefinition of DISTCLEANFILES
  - Fix: Typo, "PRECISON" to "PRECISION"
  - Replaced "AC_CONFIG_MACRO_DIR" usage with "AC_CONFIG_MACRO_DIRS"
  - Translation updates
- Changes from 4.13.3
  - Fix: Uninitialized scalar variables (CID #292062, #292063)
  - Fix: -Wcast-function-type (GCC 8)
  - Ported from dbus-glib to gdbus (bxo#14426)
  - Added support for xrandr display scaling (via Xfconf)
  - Improved display manufucturer name recognition:
  - Refreshed PNP IDs from hwdata
  - Added support for VBX (VirtualBox)
  - Standardized and shortened manufacturer names
  - Updated laptop detection to include eDP in XfceRandr
  - Updated --help copyright information to 2018
  - Translation updates
- Changes from 4.13.2
  - New: Show location of the mouse pointer on keypress
  - Fix: syncdaemon not starting with certain locales
  - Fix: division by 0 crash from gdk_screen_height_mm()
  - Fix: Remove existing socket from socket viewport (bxo#13847)
  - Fix: Use transient notifications for improved logging
  - Fix: Do not expand event sounds section so font scaling is correctly
  positioned
  - Improvements for multimonitor support:
  - Visualize all three display configuration states
  - Visually note if two displays overlap (mirrored) but are not cloned
  - Always draw active display last so it's on top
  - Fix: Correctly position monitors in extended mode
  - Fix: Race condition with monitor connect and disconnect
  - Fix: Segfault on monitor reconnect
  - Fix: Leave monitors where they were if possible (bxo#14096)
  - Deprecations:
  - Resolved GTK+ 3.22 deprecations (bxo#14273)
  - Translation updates
- Changes from 4.13.1
  - This release now requires xfconf 4.13+
  - New: Default monospace font option in the Appearance dialog
  - New: Improved support for embedded DisplayPort connectors
  - Fix: Display dialog drawing of displays
  - Fix: Display dialog DND usability issue introduced in 4.13.0
  - Fix: Make minimal dialog single instance (bxo#11169)
  - Fix: Linking to dbus-glib with xfconf 4.13+ (bxo#13633)
  - Deprecations:
  - Resolved gtk_menu_popup deprecation
  - Resolved gdk_error_trap_pop deprecation
  - Ignoring GdkScreen and GdkCairo deprecations in the display settings
  until GNOME or others find a resolution in their display management
  - Code Quality:
  - Several indentation fixes
  - Drop duplicate drawing code
  - Translation updates
- Changes from 4.13.0
  - Initial port to GTK+ 3
  - Known issues:
  - The display dialog does not always build correctly. The offending
  code exists in the port to GdkSeat. When alternating between the
  old and new versions of this code, both versions do work, so there
  seems to be some strangeness at build time.
  - See dialogs/display-settings/scrollarea.c#n513
  - Translation updates
- Clean up spec file:
  - Added conditional %%bcond_with git for easier maintanance when using
    git master branch
  - Updated URL
* Mon Apr 29 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Clean up spec file:
  - Added conditional %%bcond_with git for easier maintanance when using
    git master branch
  - Updated URL
* Fri Jun 22 2018 seife+obs@b1-systems.com
- update to 4.12.4:
  * Fix: --replace did not replace old daemon (bxo#14381)
  * Fix: Uninitialized scalar variables (CID #292062, #292063)
  * Fix: -Wcast-function-type (GCC 8)
  * Improved display manufucturer name recognition:
  - Refreshed PNP IDs from hwdata
  - Added support for VBX (VirtualBox)
  - Standardized and shortened manufacturer names
  - Updated laptop detection to include eDP in XfceRandr
  * Translation updates
* Sat Mar 24 2018 seife+obs@b1-systems.com
- update to version 4.12.3:
  * Improvements for multimonitor support:
  - Visualize all three display configuration states
  - Visually note if two displays overlap (mirrored) but are not
    cloned
  - Always draw active display last so it's on top
  - Fix: Correctly position monitors in extended mode
  - Fix: Race condition with monitor connect and disconnect
  - Fix: Segfault on monitor reconnect
  * Translation updates
* Fri Mar  2 2018 seife+obs@b1-systems.com
- update to version 4.12.2:
  - Fix: Leave monitors where they were if possible (bxo#14096)
  - Fix: syncdaemon not starting with certain locales
  - Fix: division by 0 crash from gdk_screen_height_mm()
  - New: Default monospace font option in the Appearance dialog
  - New: Improved support for embedded DisplayPort connectors
  - New: Show location of the mouse pointer on keypress
  - Translation updates
* Sun Feb 26 2017 tiwai@suse.de
- Fix buildreq for libinput stuff; it's xorg-libinput (boo#1026976)
- Enable libinput support for Leap, too (boo#1026976)
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 4.12.1:
  - fix color scheme preview on low bit depth displays
  - fix: Segfault in convert_xfce_output_info
  - fix: /Xft/Hinting is never set
  - fix memory leak in xfce4-appearance-settings
  - fix: xfsettingsd resets TV mode to NULL on power cycle
  - translation updates
* Sun May 10 2015 zaitor@opensuse.org
- Only BuildRequire libinput for 13.3 and newer, it's optional, and
  the version in 13.2 is too old anyway.
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - do not change properties on disabled libinput devices
  - increased required automake and libtool versions
  - fix crashes for missing icons (bxo#11568)
  - fix warnings during configure
  - fix primary checkbox expansion in the display settings
  - translation updates
* Tue Feb 17 2015 gber@opensuse.org
- update to version 4.11.4
  - add touchpad support with libinput
  - add previews for icon themes in appearance settings
  - add Gtk+ theme palettes in the appearance dialog
  - add support for versioned help documentation
  - add support for libinput Xorg driver (bxo#11469)
  - add option to set the primary display (bxo#8328)
  - add helper to synchronize CSD layout to xfwm4
  - support stat command flags on BSD systems (bxo#11531)
  - show more information in icon-theme list (bxo#9130)
  - width of display dialog is no longer hard-coded
  - update display PNP IDs from hwdata
  - update mimeapps.list location for glib >= 2.41 (bxo#11293)
  - use 1/10 Hz precision for displays (bxo#10661)
  - fix segmentation fault when renaming workspaces (bxo#11229)
  - fix --display argument being fatal (bxo#11188)
  - fix alignment of the sound settings
  - fix issues found with cppcheck (bxo#10879) and other
    scanning utilities
  - do not try to reencode libxklavier descriptions (bxo#11317)
  - prevent invalid characters from breaking display name
    (bxo#11423)
  - translation updates
- drop obsolete xfce4-settings-fork-before-gtk-dbus-init.patch
* Mon Aug 25 2014 gber@opensuse.org
- add xfce4-settings-fork-before-gtk-dbus-init.patch in order to
  fix problems due to forking after gtk/dbus init (bxo#11045)
* Mon Aug 25 2014 gber@opensuse.org
- update to version 4.11.3
  - reapply settings when external keyboard connects
  - new display settings dialog
  - update the settings editor to match xfconf
  - fix overlap variable shadowing a global function
  - fork before gtk/dbus init
  - add support for upower 0.99
  - translation updates
* Thu May  1 2014 gber@opensuse.org
- update to version 4.11.2
  - increase double click time to 400ms (bxo#10562)
  - show/hide display popups with focus
  - add hotplug checkbox to plug dialog
  - identify Displays button
  - fix display mirroring
  - make mirror button insensitive if not possible
  - automatically re-enable Laptop-displays if all other displays
    get disconnected
  - add option to automatically show minimal-display dialog when
    new display gets connected
  - fix bugs with mnemonic accelerators (bxo#9302 and bxo#9308)
  - rework accelerators (bxo#9302 and box#9308)
  - autotools updates
  - make touchpad type delay configurable (bxo#8948)
  - mention no cache file for icon themes
  - support circular scrolling in the synaptics settings
  - make sure AccessXKeys control is disabled by default
  - lots of improvements in XKB code
  - xsettingsd: Unset input method properties (bxo#5437)
  - appearance: Fix gtk3 theme detection in install script
    (bxo#9272)
  - show Strv arrays in the xfconf settings editor renderer
  - lot of improvements in the display code: support extended
    desktop
    mode for 2 monitors, improve minimal dialog
  - xfsettingsd: Check for NoSuchExtension (bxo#9390)
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 4.10.1
  - autotools updates
  - xsettingsd: Unset input method properties
  - appearance: Fix gtk3 theme detection in install script
  - xfsettingsd: Check service name of NameOwnerChanged
  - translation updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - use the more generic application-x-executable icon for MIME
    editor
  - Xsettings: fix an alignment problem seen on PPC
  - translation updates
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.5
  - fix display rate matching
  - bump package dependency versions
  - fix missing : in Xft.hintstyle
  - set Xcursor resources too
  - fix typo in appearance error
  - add hardcoded fallback if menu is not found
  - translation updates
* Fri Apr 13 2012 gber@opensuse.org
- add back X-XFCE category to all desktop files until XFCE is
  supported by %%suse_update_desktop_file
- fix non-existent icon name in xfce4-mime-settings.desktop
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.4
  - fix compilation without device property support
  - Xfsettingsd: don't set large dpi in xrdb
  - include xscreensaver in the manager dialog
  - complete theme installation script
  - Settings editor: set sensitivity of save button on init
  - Xfsettingsd: properly round display refresh rate to find match
  - add mime icons in the mime-editor treeview
  - store window and column sizes in xfconf
  - add cateogry based settings manager
  - re-add support for pluggable dialogs and enable them always
  - rework settings editor
  - clear out keyboard shortcuts before resetting to defaults
  - use daemon() for xfsettingsd if available
  - hide the xfconfd-already running message completely
  - excluded items with NoDisplay=true in the settings dialog
  - remove duplicated accelerators
  - add theme dnd-installation by dropping in a treeview
  - drop AC_LIBTOOL in favor of LT_PREREQ and LT_INIT
  - wait for the window manager before setting workspace names
  - add option to disable numlock restoring
  - add Help button and make existing buttons work with wiki
  - add new MIME Type editor
  - depend on Gtk+ 2.20 and Glib 2.24
  - merge xfce4-settings-helper into xfsettingsd
  - add support to xfsettingsd for pointing device properties
  - rework the mouse dialog and add support for basic synaptics
    and wacom settings
  - add option to enable assistive technologies during login
  - add fontconfig monitoring
  - improved debugging with XFSETTINGSD_DEBUG=1
  - updated translation
- dropped obsolete
  xfce4-settings-fix-keyboard-shortcut-settings.patch
* Fri Mar 30 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- added xfce4-settings-fix-keyboard-shortcut-settings.patch in
  order to clear out all old entries in the list of shortcuts when
  resetting the keyboard shortcuts in order to prevent duplicates
  (bxo#8138)
* Fri Sep 23 2011 gber@opensuse.org
- update to version 4.8.3
  - do not use freed memory
  - translation updates
* Wed Sep 21 2011 andrea.turrini@gmail.com
- fixed typos in xfce4-settings.spec
* Mon Sep 19 2011 gber@opensuse.org
- update to version 4.8.2
  - set sensitivity of custom dpi spinner
  - remove unused code and variables.
  - bugfixes
  - translation updates
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
* Thu Feb  3 2011 gber@opensuse.org
- update to version 4.8.1
  - bugfixes
  - tanslation updates
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - bugfixes
* Sat Jan 15 2011 gber@opensuse.org
- fixed typo
* Sat Jan 15 2011 gber@opensuse.org
- do not require but recommend -lang subpackage
* Tue Jan 11 2011 gber@opensuse.org
- removed dependency on xfconf
* Wed Jan  5 2011 gber@opensuse.org
- use consistent wording for the branding package
* Mon Dec 27 2010 gber@opensuse.org
- corrected URL
- corrected license
- improved summaries/descriptions
- added proper BRAND comment
- handle desktop files with %%%%suse_update_desktop_file
- mark configurations files as such
- split off -lang subpackage
- remove unsupported locales
- removed empty README
- show compiler output
- enable sound settings
- enable pluggable dialogs
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.6
  - Add checks for API change in libnotify 0.7.0.
- updated to 4.7.5
  - Use xfconf_channel_get instead of xfconf_channel_new.
  - Don't activate numlock on first launch.
  - Fix wrong capitalizations of Xfce.
  - Fix compiler warnings.
  - Drop Xfce from the settings manager .desktop name.
  - Fix free of invalid memory (bug #6909).
  - Translations updates (hu, zh_CN, he, pt, gl).
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Fri Nov 26 2010 andrea@opensuse.org
- new upstream version 4.7.4
* Wed Jan 13 2010 prusnak@suse.cz
-  updated to 4.6.4
  - Fix /Net/CursorBlinkTime property typo (bug #5488).
  - Improve error handling when setting the button map (part of bug #5004).
  - Fix the check for Xi so it does not fail with Xi2 (bug #4929).
  - Translation updates (ru, ja).
* Wed Nov 11 2009 prusnak@suse.cz
- updated to 4.6.3
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Mon Aug 18 2008 prusnak@suse.cz
- created package (version 4.5.80)
